"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }var _path = require('path'); var _path2 = _interopRequireDefault(_path);
var _crypto = require('crypto'); var _crypto2 = _interopRequireDefault(_crypto);
var _fsextra = require('fs-extra'); var _fsextra2 = _interopRequireDefault(_fsextra);
var _picocolors = require('picocolors'); var _picocolors2 = _interopRequireDefault(_picocolors);
var _getPaths = require('./getPaths');
const validateKeyAndCerts = ({
  cert,
  key,
  crtFilePath,
  keyFilePath
}) => {
  let encrypted;
  try {
    encrypted = _crypto2.default.publicEncrypt(cert, Buffer.from("test"));
  } catch (err) {
    throw new Error(
      `The certificate "${_picocolors2.default.yellow(crtFilePath)}" is invalid.
${err.message}`
    );
  }
  try {
    _crypto2.default.privateDecrypt(key, encrypted);
  } catch (err) {
    throw new Error(
      `The certificate key "${_picocolors2.default.yellow(keyFilePath)}" is invalid.
${err.message}`
    );
  }
};
const readEnvFile = (file, type) => {
  if (!_fsextra2.default.existsSync(file)) {
    throw new Error(
      `You specified ${_picocolors2.default.cyan(
        type
      )} in your env, but the file "${_picocolors2.default.yellow(file)}" can't be found.`
    );
  }
  return _fsextra2.default.readFileSync(file);
};
const getHttpsConfig = () => {
  const paths = _getPaths.getPaths.call(void 0, );
  const { SSL_CRT_FILE_PATH, SSL_KEY_FILE_PATH, USE_HTTPS } = process.env;
  const useHttps = USE_HTTPS === "true";
  if (useHttps && SSL_CRT_FILE_PATH && SSL_KEY_FILE_PATH) {
    const crtFilePath = _path2.default.resolve(paths.appPath, SSL_CRT_FILE_PATH);
    const keyFilePath = _path2.default.resolve(paths.appPath, SSL_KEY_FILE_PATH);
    const config = {
      cert: readEnvFile(crtFilePath, "SSL_CRT_FILE_PATH"),
      key: readEnvFile(keyFilePath, "SSL_KEY_FILE_PATH")
    };
    validateKeyAndCerts({ ...config, crtFilePath, keyFilePath });
    return config;
  }
  return useHttps;
};


exports.getHttpsConfig = getHttpsConfig;
