"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }var _path = require('path'); var _path2 = _interopRequireDefault(_path);
var _fsextra = require('fs-extra'); var _fsextra2 = _interopRequireDefault(_fsextra);
var _ModuleScopePlugin = require('react-dev-utils/ModuleScopePlugin'); var _ModuleScopePlugin2 = _interopRequireDefault(_ModuleScopePlugin);
var _getEnv = require('./getEnv');
var _getPaths = require('./getPaths');
var _getModules = require('./getModules');
var _getPlugins = require('./getPlugins');
var _getModuleRules = require('./getModuleRules');
var _getOptimization = require('./getOptimization');
var _utils = require('../utils');
const getWebpackConfig = () => {
  const isEnvDevelopment = process.env.NODE_ENV === "development";
  const isEnvProduction = process.env.NODE_ENV === "production";
  const useSourceMap = process.env.USE_SOURCEMAP === "true";
  const useProfile = process.env.USE_PROFILE === "true";
  const paths = _getPaths.getPaths.call(void 0, );
  const modules = _getModules.getModules.call(void 0, );
  const env = _getEnv.getEnv.call(void 0, paths.publicUrlOrPath.slice(0, -1));
  return {
    target: ["browserslist"],
    // Webpack noise constrained to errors and warnings
    stats: "errors-warnings",
    mode: isEnvProduction ? "production" : isEnvDevelopment ? "development" : void 0,
    // Stop compilation early in production
    bail: isEnvProduction,
    devtool: isEnvProduction ? useSourceMap ? "source-map" : false : isEnvDevelopment && "cheap-module-source-map",
    // These are the "entry points" to our application.
    // This means they will be the "root" imports that are included in JS bundle.
    entry: paths.appIndexJs,
    output: {
      // The dist folder.
      path: paths.appDist,
      // Add /* filename */ comments to generated require()s in the output.
      pathinfo: isEnvDevelopment,
      // There will be one main bundle, and one file per asynchronous chunk.
      // In development, it does not produce real files.
      filename: isEnvProduction ? "static/js/[name].[contenthash:16].js" : isEnvDevelopment ? "static/js/bundle.js" : void 0,
      // There are also additional JS chunk files if you use code splitting.
      chunkFilename: isEnvProduction ? "static/js/[name].[contenthash:16].chunk.js" : isEnvDevelopment ? "static/js/[name].chunk.js" : void 0,
      assetModuleFilename: "static/media/[name].[hash][ext]",
      // webpack uses `publicPath` to determine where the app is being served from.
      // It requires a trailing slash, or the file assets will get an incorrect path.
      // We inferred the "public path" (such as / or /my-project) from homepage.
      publicPath: paths.publicUrlOrPath,
      // Point sourcemap entries to original disk location (format as URL on Windows)
      devtoolModuleFilenameTemplate: isEnvProduction ? (info) => _path2.default.relative(paths.appSrc, info.absoluteResourcePath).replace(/\\/g, "/") : isEnvDevelopment ? (info) => _path2.default.resolve(info.absoluteResourcePath).replace(/\\/g, "/") : void 0
    },
    cache: {
      type: "filesystem",
      version: _utils.getHash.call(void 0, env.raw),
      cacheDirectory: paths.appWebpackCache,
      store: "pack",
      buildDependencies: {
        defaultWebpack: ["webpack/lib/"],
        config: [__filename],
        tsconfig: [paths.appTsConfig, paths.appJsConfig].filter(
          (f) => _fsextra2.default.existsSync(f)
        )
      }
    },
    infrastructureLogging: {
      level: "none"
    },
    optimization: _getOptimization.getOptimization.call(void 0, ),
    resolve: {
      // This allows you to set a fallback for where webpack should look for modules.
      // We placed these paths second because we want `node_modules` to "win"
      // if there are any conflicts. This matches Node resolution mechanism.
      // https://github.com/facebook/create-react-app/issues/253
      modules: ["node_modules", paths.appNodeModules].concat(
        modules.additionalModulePaths || []
      ),
      // These are the reasonable defaults supported by the Node ecosystem.
      // We also include JSX as a common component filename extension to support
      // some tools, although we do not recommend using it, see:
      // https://github.com/facebook/create-react-app/issues/290
      // `web` extension prefixes have been added for better support
      // for React Native Web.
      extensions: paths.moduleFileExtensions.map((ext) => `.${ext}`),
      alias: {
        "@": paths.appSrc,
        // Allows for better profiling with ReactDevTools
        ...isEnvProduction && useProfile ? {
          "react-dom$": "react-dom/profiling",
          "scheduler/tracing": "scheduler/tracing-profiling"
        } : {},
        ...modules.webpackAliases
      },
      plugins: [
        // Prevents users from importing files from outside of src/ (or node_modules/).
        // This often causes confusion because we only process files within src/ with babel.
        // To fix this, we prevent you from importing files out of src/ -- if you'd like to,
        // please link the files into your node_modules/ and let module-resolution kick in.
        // Make sure your source files are compiled, as they will not be processed in any way.
        new (0, _ModuleScopePlugin2.default)(paths.appSrc, [
          paths.appPackageJson,
          require.resolve("react-refresh/runtime"),
          require.resolve("@pmmmwh/react-refresh-webpack-plugin"),
          require.resolve("@mango-scripts/babel-preset-mango/source"),
          require.resolve("@babel/runtime/helpers/esm/assertThisInitialized", {
            paths: [
              require.resolve("@mango-scripts/babel-preset-mango/source")
            ]
          }),
          require.resolve("@babel/runtime/regenerator", {
            paths: [
              require.resolve("@mango-scripts/babel-preset-mango/source")
            ]
          })
        ])
      ]
    },
    module: {
      parser: { javascript: { strictExportPresence: true } },
      rules: _getModuleRules.getModuleRules.call(void 0, )
    },
    plugins: _getPlugins.getPlugins.call(void 0, ),
    // Turn off performance processing because we utilize
    // our own hints via the FileSizeReporter
    performance: false
  };
};


exports.getWebpackConfig = getWebpackConfig;
