import { MinifyOptions } from 'terser';
import { Options } from '@swc/core';
import { TransformOptions } from 'esbuild';

type ConfigType = {
    /**
     * output directory
     * @type {string}
     * @default dist
     */
    distDir?: string;
    /**
     * loader config
     */
    loader?: {
        babel?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        less?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        sass?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        stylus?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        postcss?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        swc?: {
            /**
             * enable
             * @default false
             */
            enable: boolean;
            options?: Options;
        };
        esbuild?: {
            /**
             * enable
             * @default false
             */
            enable: boolean;
            options?: TransformOptions;
        };
    };
    /**
     * plugin config
     */
    plugin?: {
        /**
         * eslint-webpack-plugin config
         */
        eslint?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        /**
         * stylelint-webpack-plugin config
         */
        stylelint?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
        /**
         *   react-dev-utils/ForkTsCheckerWebpackPlugin config
         */
        typescript?: {
            /**
             * enable
             * @default true
             */
            enable: boolean;
            options?: Record<string, any>;
        };
    };
    /**
     * webpack optimization config
     */
    optimization?: {
        /**
         * webpack optimization config
         */
        splitChunks?: any;
        /**
         * webpack minimizer config
         */
        minimizer?: {
            /**
             * jsMinimizer config
             */
            jsMinimizer?: {
                /**
                 * minify
                 * @default 'terserMinify'
                 */
                minify: 'terserMinify' | 'uglifyJsMinify' | 'esbuildMinify' | 'swcMinify';
                terserOptions?: MinifyOptions;
            };
            /**
             * cssMinimizer config
             */
            cssMinimizer?: {
                /**
                 * minify
                 * @default 'cssnanoMinify'
                 */
                minify: 'cssnanoMinify' | 'cssoMinify' | 'cleanCssMinify' | 'esbuildMinify' | 'lightningCssMinify' | 'swcMinify';
                minimizerOptions?: Record<string, any>;
            };
        };
    };
};
declare const defaultUserConfig: ConfigType;
declare function defineConfig(config: ConfigType): ConfigType;

export { type ConfigType, defaultUserConfig, defineConfig };
